// Dua data for different feelings
const duas = {
    'happy': {
        dua: 'اللّهُــمَّ اجْعلْني مِنَ السَّارِرِينَ',
        tarjuma: 'O Allah, make me among the happy ones.',
        verse: 'Surah At-Tawbah, 9:103',
        verse_ref: 'وَصَلِّ اللّهُمَّ عَلَىٰ مُحَمَّدٍ وَآلِهِ وَسَلِّمْ'
    },
    'sad': {
        dua: 'اللّهُــمَّ اجْعَلْنِي صَابِرًا',
        tarjuma: 'O Allah, make me patient.',
        verse: 'Surah Al-Baqarah, 2:153',
        verse_ref: 'إِنَّ اللَّهَ مَعَ الصَّابِرِينَ'
    },
    'grateful': {
        dua: 'اللّهُــمَّ اجْعَلْنِي مِنَ الشَّاكِرِينَ',
        tarjuma: 'O Allah, make me among the grateful ones.',
        verse: 'Surah Ibrahim, 14:7',
        verse_ref: 'لَئِنْ شَكَرْتُمْ لَأَزِيدَنَّكُمْ'
    },
    'anxious': {
        dua: 'اللّهُــمَّ طَهِّرْ قَلْبِي مِنَ القَلَقِ',
        tarjuma: 'O Allah, purify my heart from anxiety.',
        verse: 'Surah Ash-Sharh, 94:5',
        verse_ref: 'فَإِنَّ مَعَ الْعُسْرِ يُسْرًا'
    },
    'peaceful': {
        dua: 'اللّهُــمَّ اجْعَلْنِي مِنَ الرَّاضِينَ',
        tarjuma: 'O Allah, make me among the content ones.',
        verse: 'Surah Al-Fajr, 89:27',
        verse_ref: 'يَا أَيَّتُهَا النَّفْسُ ٱلْمُطْمَئِنَّةُ'
    }
};

// Handle Generate Dua based on selected feeling
document.getElementById('generateDuaBtn').addEventListener('click', function () {
    const feeling = document.getElementById('feelingSelect').value;
    generateDua(feeling);
});

// Handle Random Dua button click
document.getElementById('randomDuaBtn').addEventListener('click', function () {
    const feelings = ['happy', 'sad', 'grateful', 'anxious', 'peaceful'];
    const randomFeeling = feelings[Math.floor(Math.random() * feelings.length)];
    generateDua(randomFeeling);
});

// Function to generate and display Dua, Translation, and Quranic Verse
function generateDua(feeling) {
    const { dua, tarjuma, verse, verse_ref } = duas[feeling];

    // Display the Dua, Tarjuma, and Quranic Verse
    const resultHTML = `
        <p><strong>Dua:</strong> ${dua}</p>
        <p class="tarjuma"><strong>Tarjuma:</strong> ${tarjuma}</p>
        <p class="verse"><strong>Quranic Verse:</strong> ${verse}</p>
        <p><em>${verse_ref}</em></p>
    `;
    
    document.getElementById('duaResult').innerHTML = resultHTML;
}

// Save the current dua to localStorage
document.getElementById('saveDuaBtn').addEventListener('click', function () {
    const currentDua = document.querySelector('#duaResult p').textContent;
    const savedDuas = JSON.parse(localStorage.getItem('savedDuas')) || [];
    savedDuas.push(currentDua);
    localStorage.setItem('savedDuas', JSON.stringify(savedDuas));

    loadSavedDuas();
});

// Load saved duas from localStorage
function loadSavedDuas() {
    const savedDuas = JSON.parse(localStorage.getItem('savedDuas')) || [];
    const savedDuaList = document.getElementById('savedDuaList');
    savedDuaList.innerHTML = '';

    savedDuas.forEach((dua, index) => {
        const li = document.createElement('li');
        li.textContent = dua;
        const deleteBtn = document.createElement('button');
        deleteBtn.textContent = 'Delete';
        deleteBtn.addEventListener('click', () => deleteSavedDua(index));
        li.appendChild(deleteBtn);
        savedDuaList.appendChild(li);
    });
}

// Delete a saved dua from localStorage
function deleteSavedDua(index) {
    const savedDuas = JSON.parse(localStorage.getItem('savedDuas')) || [];
    savedDuas.splice(index, 1);
    localStorage.setItem('savedDuas', JSON.stringify(savedDuas));
    loadSavedDuas();
}

// Call loadSavedDuas when the page loads to display any saved duas
window.onload = loadSavedDuas;


